function [OutageTime,Loss,Customers,RestorationTime,Cause] = importfile(workbookFile,sheetName,startRow,endRow)
%IMPORTFILE Import data from a spreadsheet
%   [OutageTime,Loss,Customers,RestorationTime,Cause] = IMPORTFILE(FILE)
%   reads data from the first worksheet in the Microsoft Excel spreadsheet
%   file named FILE and returns the data as column vectors.
%
%   [OutageTime,Loss,Customers,RestorationTime,Cause] =
%   IMPORTFILE(FILE,SHEET) reads from the specified worksheet.
%
%   [OutageTime,Loss,Customers,RestorationTime,Cause] =
%   IMPORTFILE(FILE,SHEET,STARTROW,ENDROW) reads from the specified
%   worksheet for the specified row interval(s). Specify STARTROW and
%   ENDROW as a pair of scalars or vectors of matching size for
%   dis-contiguous row intervals. To read to the end of the file specify an
%   ENDROW of inf.
%
%	Rows with non-numeric cells are excluded.
%
% Example:
%   [OutageTime,Loss,Customers,RestorationTime,Cause] =
%   importfile('data.xls','List1',2,8);
%
%   See also XLSREAD.

% Auto-generated by MATLAB on 2014/12/19 14:16:31

%% Input handling

% If no sheet is specified, read first sheet
if nargin == 1 || isempty(sheetName)
    sheetName = 1;
end

% If row start and end points are not specified, define defaults
if nargin <= 3
    startRow = 2;
    endRow = 8;
end

%% Import the data, extracting spreadsheet dates in Excel serial date format
[~, ~, raw, dates] = xlsread(workbookFile, sheetName, sprintf('A%d:E%d',startRow(1),endRow(1)),'' , @convertSpreadsheetExcelDates);
for block=2:length(startRow)
    [~, ~, tmpRawBlock,tmpDateNumBlock] = xlsread(workbookFile, sheetName, sprintf('A%d:E%d',startRow(block),endRow(block)),'' , @convertSpreadsheetExcelDates);
    raw = [raw;tmpRawBlock]; %#ok<AGROW>
    dates = [dates;tmpDateNumBlock]; %#ok<AGROW>
end
raw(cellfun(@(x) ~isempty(x) && isnumeric(x) && isnan(x),raw)) = {''};
cellVectors = raw(:,[2,5]);
raw = raw(:,3);
dates = dates(:,[1,4]);

%% Exclude rows with non-numeric cells
I = ~(all(cellfun(@(x) (isnumeric(x) || islogical(x)) && ~isnan(x),raw),2) & all(cellfun(@isnumeric,dates),2)); % Find rows with non-numeric cells
raw(I,:) = [];
cellVectors(I,:) = [];
dates(I,:) = [];

%% Create output variable
J = cellfun(@(x) ischar(x), raw);
raw(J) = {NaN};
data = reshape([raw{:}],size(raw));

%% Allocate imported array to column variable names
dates(~cellfun(@(x) isnumeric(x) || islogical(x), dates)) = {NaN};
OutageTime = datetime([dates{:,1}].', 'ConvertFrom', 'Excel');
Loss = cellVectors(:,1);
Customers = data(:,1);
RestorationTime = datetime([dates{:,2}].', 'ConvertFrom', 'Excel');
Cause = cellVectors(:,2);

% For code requiring serial dates (datenum) instead of datetime, uncomment
% the following line(s) below to return the imported dates as datenum(s).

% OutageTime=datenum(OutageTime);
% RestorationTime=datenum(RestorationTime);

